==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/denier/DenierSpecFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.denier;

import me.snowdrop.istio.api.Status;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import javax.validation.Valid;
import me.snowdrop.istio.api.StatusFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import me.snowdrop.istio.api.StatusBuilder;
import java.lang.Boolean;

public class DenierSpecFluentImpl<A extends DenierSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements DenierSpecFluent<A>{

    private StatusBuilder status;
    private Long validDuration;
    private Integer validUseCount;

    public DenierSpecFluentImpl(){
    }
    public DenierSpecFluentImpl(DenierSpec instance){
            this.withStatus(instance.getStatus()); 
            this.withValidDuration(instance.getValidDuration()); 
            this.withValidUseCount(instance.getValidUseCount()); 
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.Status getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public me.snowdrop.istio.api.Status buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(me.snowdrop.istio.api.Status status){
            _visitables.remove(this.status);
            if (status!=null){ this.status= new StatusBuilder(status); _visitables.add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public DenierSpecFluent.ApiStatusNested<A> withNewApiStatus(){
            return new ApiStatusNestedImpl();
    }

    public DenierSpecFluent.ApiStatusNested<A> withNewStatusLike(me.snowdrop.istio.api.Status item){
            return new ApiStatusNestedImpl(item);
    }

    public DenierSpecFluent.ApiStatusNested<A> editApiStatus(){
            return withNewStatusLike(getStatus());
    }

    public DenierSpecFluent.ApiStatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new StatusBuilder().build());
    }

    public DenierSpecFluent.ApiStatusNested<A> editOrNewStatusLike(me.snowdrop.istio.api.Status item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public Long getValidDuration(){
            return this.validDuration;
    }

    public A withValidDuration(Long validDuration){
            this.validDuration=validDuration; return (A) this;
    }

    public Boolean hasValidDuration(){
            return this.validDuration != null;
    }

    public A withNewValidDuration(String arg1){
            return (A)withValidDuration(new Long(arg1));
    }

    public A withNewValidDuration(long arg1){
            return (A)withValidDuration(new Long(arg1));
    }

    public Integer getValidUseCount(){
            return this.validUseCount;
    }

    public A withValidUseCount(Integer validUseCount){
            this.validUseCount=validUseCount; return (A) this;
    }

    public Boolean hasValidUseCount(){
            return this.validUseCount != null;
    }

    public A withNewValidUseCount(String arg1){
            return (A)withValidUseCount(new Integer(arg1));
    }

    public A withNewValidUseCount(int arg1){
            return (A)withValidUseCount(new Integer(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            DenierSpecFluentImpl that = (DenierSpecFluentImpl) o;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            if (validDuration != null ? !validDuration.equals(that.validDuration) :that.validDuration != null) return false;
            if (validUseCount != null ? !validUseCount.equals(that.validUseCount) :that.validUseCount != null) return false;
            return true;
    }


    public class ApiStatusNestedImpl<N> extends StatusFluentImpl<DenierSpecFluent.ApiStatusNested<N>> implements DenierSpecFluent.ApiStatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final StatusBuilder builder;
    
            ApiStatusNestedImpl(me.snowdrop.istio.api.Status item){
                    this.builder = new StatusBuilder(this, item);
            }
            ApiStatusNestedImpl(){
                    this.builder = new StatusBuilder(this);
            }
    
    public N and(){
            return (N) DenierSpecFluentImpl.this.withStatus(builder.build());
    }
    public N endApiStatus(){
            return and();
    }

}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/denier/DenierSpecFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.denier;

import me.snowdrop.istio.api.Status;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Integer;
import java.lang.Deprecated;
import me.snowdrop.istio.api.StatusFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import me.snowdrop.istio.api.StatusBuilder;
import java.lang.Boolean;

public class DenierSpecFluentImpl<A extends DenierSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements DenierSpecFluent<A>{

    private StatusBuilder status;
    private Integer validDuration;
    private Integer validUseCount;

    public DenierSpecFluentImpl(){
    }
    public DenierSpecFluentImpl(DenierSpec instance){
            this.withStatus(instance.getStatus()); 
            this.withValidDuration(instance.getValidDuration()); 
            this.withValidUseCount(instance.getValidUseCount()); 
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public Status getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public Status buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(Status status){
            _visitables.get("status").remove(this.status);
            if (status!=null){ this.status= new StatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public DenierSpecFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public DenierSpecFluent.StatusNested<A> withNewStatusLike(Status item){
            return new StatusNestedImpl(item);
    }

    public DenierSpecFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public DenierSpecFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new StatusBuilder().build());
    }

    public DenierSpecFluent.StatusNested<A> editOrNewStatusLike(Status item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public Integer getValidDuration(){
            return this.validDuration;
    }

    public A withValidDuration(Integer validDuration){
            this.validDuration=validDuration; return (A) this;
    }

    public Boolean hasValidDuration(){
            return this.validDuration != null;
    }

    public Integer getValidUseCount(){
            return this.validUseCount;
    }

    public A withValidUseCount(Integer validUseCount){
            this.validUseCount=validUseCount; return (A) this;
    }

    public Boolean hasValidUseCount(){
            return this.validUseCount != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            DenierSpecFluentImpl that = (DenierSpecFluentImpl) o;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            if (validDuration != null ? !validDuration.equals(that.validDuration) :that.validDuration != null) return false;
            if (validUseCount != null ? !validUseCount.equals(that.validUseCount) :that.validUseCount != null) return false;
            return true;
    }


    public class StatusNestedImpl<N> extends StatusFluentImpl<DenierSpecFluent.StatusNested<N>> implements DenierSpecFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final StatusBuilder builder;
    
            StatusNestedImpl(Status item){
                    this.builder = new StatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new StatusBuilder(this);
            }
    
    public N and(){
            return (N) DenierSpecFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}
